import { Component, Inject, ViewEncapsulation, ViewChild } from "@angular/core";
import { createElement } from "@syncfusion/ej2-base";
import { DropDownList } from "@syncfusion/ej2-dropdowns";
import { CheckBox } from "@syncfusion/ej2-buttons";
import { NzModalModule, NzModalRef, NzModalService } from "ng-zorro-antd/modal";
import { NumericTextBox } from "@syncfusion/ej2-inputs";

import {
  ScheduleComponent,
  View,
  RenderCellEventArgs,
  EventRenderedArgs,
  MonthService,
  DayService,
  WeekService,
  EventClickArgs,
  WorkWeekService,
  EventSettingsModel,
  TimelineMonthService,
  ResizeService,
  DragAndDropService,
  CellClickEventArgs,
  PopupOpenEventArgs,
  WorkHoursModel,
  TimeScaleModel,
  DragEventArgs,
  ResizeEventArgs,
  ActionEventArgs,
} from "@syncfusion/ej2-angular-schedule";
import { Internationalization, extend } from "@syncfusion/ej2-base";
import { scheduleData } from "./data";
import { DraftComponent } from "src/app/pages/publish/menu/draft/draft.component";

@Component({
  selector: "calendar-component",
  templateUrl: "./calendar.component.html",
  styleUrls: ["./calendar.component.scss"],
  providers: [
    MonthService,
    DayService,
    WeekService,
    WorkWeekService,
    TimelineMonthService,
    ResizeService,
    DragAndDropService,
  ],
  encapsulation: ViewEncapsulation.None,
})
export class CalendarComponent {
  public scheduleObj: ScheduleComponent;
  public draftComponent: DraftComponent;
  public eventSettings: EventSettingsModel = {
    dataSource: <Object[]>extend([], scheduleData, null, true),
  };

  public workHours: WorkHoursModel = {
    start: "00:00",
    end: "23:59",
    highlight: false,
  };
  public currentView: View = "Week";
  isVisible = false;
  public intervalValue: string = "60";
  public selectedDate: Date = new Date(Date.now());
  public instance: Internationalization = new Internationalization();

  // constructor(private postsService: PostsService) {}
  @ViewChild("scheduleObj", { static: false })
  @ViewChild("draftComponent", { static: false })
  workHour(): void {
    let dates: Date[] = [new Date(Date.now()), new Date(Date.now())];
    this.scheduleObj.setWorkHours(dates, "11:00", "20:00");
  }

  getDateHeaderText(value: Date): string {
    return this.instance.formatDate(value, { skeleton: "Ed" });
  }

  public timeScale: TimeScaleModel = {
    enable: true,
    interval: 60,
    slotCount: 4,
  };

  // Render the data in each cell
  OnRenderCell(args: RenderCellEventArgs): void {
    if (args.elementType === "monthCells" && this.currentView === "Month") {
      let ele: Element = document.createElement("div");
      args.element.appendChild(ele.firstChild);
    }
    if (args.element.classList.contains("e-work-cells")) {
      let today = new Date(new Date().setHours(0, 0, 0, 0)).getTime();
      let cellDate = new Date(args.date.setHours(0, 0, 0, 0)).getTime();
      if (cellDate === today) {
        args.element.classList.add("today-bg");
      }
    }
  }

  onCellDoubleClick(args: CellClickEventArgs) {
    console.log("cell click called");
    this.isVisible = false;
    args.cancel = true;
  }

  onEventClicked(args: EventClickArgs): void {
    console.log("onEventClicked");
    return;
  }

  onEventRendered(args: EventRenderedArgs): void {
    console.log("event rendered called");
    let categoryColor: string = args.data.CategoryColor as string;
    if (!args.element || !categoryColor) {
      return;
    }
    if (this.currentView === "Agenda") {
      (args.element
        .firstChild as HTMLElement).style.borderLeftColor = categoryColor;
    } else {
      args.element.style.backgroundColor = categoryColor;
    }
  }
  //On clicking of a Cell Create Post Modal will open
  onCellClick(args: CellClickEventArgs) {
    console.log("cell click called", args);
    args.cancel = true;
    // this.showModal();
  }

  public onPopupOpen(args: PopupOpenEventArgs): void {
    console.log("pop up open click called");
    if (
      (!args.target.classList.contains("e-appointment") &&
        args.type === "QuickInfo") ||
      args.type === "Editor"
    ) {
      args.cancel = this.onEventCheck(args);
      this.showModal();
      console.log("call in pop open", args.cancel);
    }
  }
  public onDragStop(args: DragEventArgs): void {
    args.cancel = this.onEventCheck(args);
  }
  public onResizeStop(args: ResizeEventArgs): void {
    args.cancel = this.onEventCheck(args);
  }

  public onActionBegin(args: ActionEventArgs): void {
    if (
      args.requestType === "eventCreate" ||
      args.requestType === "eventChange"
    ) {
      args.cancel = this.onEventCheck(args);
    }
  }
  //Check if a event is greater than or less than from current Date
  public onEventCheck(args: any): boolean {
    console.log(args);
    let eventObj: any = args.data instanceof Array ? args.data[0] : args.data;
    return eventObj.StartTime < new Date();
  }

  showModal(): void {
    this.isVisible = true;
    console.log("modal");
  }

  handleOk(): void {
    console.log("Button ok clicked!");
    this.isVisible = false;
  }

  handleCancel(): void {
    console.log("Button cancel clicked!");
    this.isVisible = false;
  }
}
